@@ -25,9 +25,9 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py 1995 2007-02-11 16:40:57Z wwalker $"
-__version__   = "$Revision: 1995 $"
-__date__      = "$Date: 2007-02-11 11:40:57 -0500 (Sun, 11 Feb 2007) $"
+__id__        = "$Id: braille.py 2174 2007-03-14 19:33:59Z richb $"
+__version__   = "$Revision: 2174 $"
+__date__      = "$Date: 2007-03-14 15:33:59 -0400 (Wed, 14 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -63,8 +63,8 @@ except:
     pass
 import debug
 import eventsynthesizer
+import orca_state
 import settings
-import util
 
 from orca_i18n import _                          # for gettext support
 from rolenames import getShortBrailleForRoleName # localized role names
@@ -311,8 +311,9 @@ class Text(Region):
         """
 
         self.accessible = accessible
-        [string, self.caretOffset, self.lineOffset] = \
-                 util.getTextLineAtCaret(self.accessible)
+        if orca_state.activeScript:
+            [string, self.caretOffset, self.lineOffset] = \
+                 orca_state.activeScript.getTextLineAtCaret(self.accessible)
 
         # Sometimes, gnome-terminal will give us very odd values when
         # the user is editing using 'vi' and has positioned the caret
@@ -345,7 +346,7 @@ class Text(Region):
         """
 
         [string, caretOffset, lineOffset] = \
-                 util.getTextLineAtCaret(self.accessible)
+                 orca_state.activeScript.getTextLineAtCaret(self.accessible)
         cursorOffset = caretOffset - lineOffset
         if self.label:
             cursorOffset += len(self.label.decode("UTF-8")) + 1
@@ -689,12 +690,12 @@ def refresh(panToCursor=True, targetCursorCell=0):
                 # The name before BrlTTY v3.8 revision 2810
                 #
                 writeStruct = brlapi.Write()
-            writeStruct.text = substring
             writeStruct.regionBegin = 1
             writeStruct.regionSize = len(substring.decode("UTF-8"))
             while writeStruct.regionSize < _displaySize[0]:
-                writeStruct.text += " "
+                substring += " "
                 writeStruct.regionSize += 1
+            writeStruct.text = substring
             writeStruct.cursor = cursorCell
             writeStruct.charset = "UTF-8"
 
