@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,10 +19,10 @@
 
 """Provides the FocusTrackingPresenter for Orca."""
 
-__id__        = "$Id: focus_tracking_presenter.py 1996 2007-02-11 18:07:28Z joanied $"
-__version__   = "$Revision: 1996 $"
-__date__      = "$Date: 2007-02-11 13:07:28 -0500 (Sun, 11 Feb 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: focus_tracking_presenter.py 2173 2007-03-14 15:33:38Z richb $"
+__version__   = "$Revision: 2173 $"
+__date__      = "$Date: 2007-03-14 11:33:38 -0400 (Wed, 14 Mar 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import gobject
@@ -40,7 +40,6 @@ import presentation_manager
 import rolenames
 import settings
 import speech
-import util
 
 from orca_i18n import _ # for gettext support
 
@@ -419,7 +418,10 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                 atspi.Accessible.deleteAccessible(event.source)
                 return
 
-            debug.printDetails(debug.LEVEL_FINEST, "    ", event.source)
+            if (not debug.eventDebugFilter) \
+                or (debug.eventDebugFilter \
+                    and debug.eventDebugFilter.match(event.type)):
+                debug.printDetails(debug.LEVEL_FINEST, "    ", event.source)
 
         except CORBA.COMM_FAILURE:
             debug.printException(debug.LEVEL_WARNING)
@@ -478,14 +480,6 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                        or ((event.type == "focus:") \
                            and (event.source.role == rolenames.ROLE_FRAME)):
 
-                        # If old ("factory") settings don't exist yet, save
-                        # a set, else restore the old application settings.
-                        #
-                        if not self._oldAppSettings:
-                            self._oldAppSettings = util.saveOldAppSettings()
-                        else:
-                            util.restoreOldAppSettings(self._oldAppSettings)
-
                         # We'll let someone else decide if it's important
                         # to stop speech or not.
                         #speech.stop()
@@ -494,6 +488,16 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                         debug.println(debug.LEVEL_FINE, "ACTIVE SCRIPT: " \
                                       + orca_state.activeScript.name)
 
+                        # If old ("factory") settings don't exist yet, save
+                        # a set, else restore the old application settings.
+                        #
+                        if not self._oldAppSettings:
+                            self._oldAppSettings = \
+                                  orca_state.activeScript.saveOldAppSettings()
+                        else:
+                            orca_state.activeScript.restoreOldAppSettings( \
+                                                         self._oldAppSettings)
+
                         # Load in the application specific settings for the
                         # app for this event (if found).
                         #
@@ -618,8 +622,12 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                 if settings.debugEventQueue:
                     self._enqueueEventCount -= 1
                 return
-            debug.println(debug.LEVEL_FINEST,
-                          "---------> QUEUEING EVENT %s" % e.type)
+
+            if (not debug.eventDebugFilter) \
+                or (debug.eventDebugFilter \
+                    and debug.eventDebugFilter.match(e.type)):
+                debug.println(debug.LEVEL_FINEST,
+                              "---------> QUEUEING EVENT %s" % e.type)
 
         if event:
             if settings.debugEventQueue:
@@ -711,12 +719,12 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                               "\n^^^^^ PROCESS BRAILLE EVENT %d ^^^^^"\
                               % event.event)
             else:
-                debug.println(debug.LEVEL_FINEST, "DEQUEUED EVENT %s <----------" \
-                              % event.type)
-
                 if (not debug.eventDebugFilter) \
                     or (debug.eventDebugFilter \
                         and debug.eventDebugFilter.match(event.type)):
+                    debug.println(debug.LEVEL_FINEST,
+                                  "DEQUEUED EVENT %s <----------" \
+                                  % event.type)
                     debug.println(debug.eventDebugLevel,
                                   "\nvvvvv PROCESS OBJECT EVENT %s vvvvv" \
                                   % event.type)
@@ -838,8 +846,6 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
     def activate(self):
         """Called when this presentation manager is activated."""
 
-        speech.speak(_("Switching to focus tracking mode."))
-
         self._listenerCounts = {}
         self._knownScripts   = {}
         self._knownAppSettings = {}
@@ -856,7 +862,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         self._registerEventListener("window:deactivate")
         self._registerEventListener("object:children-changed:remove")
 
-        win = util.findActiveWindow()
+        win = orca_state.activeScript.findActiveWindow()
         if win:
             # Generate a fake window activation event so the application
             # can tell the user about itself.
