@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,9 +19,9 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py 1787 2006-12-06 17:33:21Z wwalker $"
-__version__   = "$Revision: 1787 $"
-__date__      = "$Date: 2006-12-06 12:33:21 -0500 (Wed, 06 Dec 2006) $"
+__id__        = "$Id: gnomespeechfactory.py 2179 2007-03-15 15:43:21Z wwalker $"
+__version__   = "$Revision: 2179 $"
+__date__      = "$Date: 2007-03-15 11:43:21 -0400 (Thu, 15 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -46,7 +46,6 @@ import punctuation_settings
 import settings
 import speech
 import speechserver
-import util
 
 from acss import ACSS
 
@@ -363,7 +362,50 @@ class SpeechServer(speechserver.SpeechServer):
         if self.__speakers.has_key(acss.name()):
             return self.__speakers[acss.name()]
 
-        # Create a new voice for all unique ACSS's we see.
+        # Search for matching languages first, as that is the most
+        # important thing.  We also try to look for the desired language
+        # first, but then fall back to the default language.
+        #
+        languages = []
+        try:
+            if acss.has_key(ACSS.FAMILY):
+                family = acss[ACSS.FAMILY]
+                languages = [family[speechserver.VoiceFamily.LOCALE]]
+            elif defaultACSS.has_key(ACSS.FAMILY):
+                family = defaultACSS[ACSS.FAMILY]
+                languages = [family[speechserver.VoiceFamily.LOCALE]]
+        except:
+            pass
+
+        # [[[TODO: WDW - I'm using an array of languages here because
+        # it will give us the opportunity to provide a match for
+        # gnome-speech driver implementations that do not designate
+        # languages using the combination of ISO 639-1 and 3166-1
+        # language_region strings (e.g., they use 'english' instead of
+        # "en_US").  Thus, we could detect the default language is
+        # "en_US" and just automatically append "english" and such to
+        # the list to allow us to accomodate these kind of
+        # variants.]]]
+        #
+        if len(languages) == 0:
+            import locale
+            language, encoding = locale.getdefaultlocale()
+            languages = [language]
+
+        voices = self.__driver.getAllVoices()
+        foundVoices = []
+        for voice in voices:
+            if voice.language in languages:
+                foundVoices.append(voice)
+
+        # If we didn't find any matches, well...punt.
+        #
+        if len(foundVoices):
+            voices = foundVoices
+        else:
+            voices = self.__driver.getAllVoices()
+
+        # Now search for a matching family name.
         #
         familyName = None
         if acss.has_key(ACSS.FAMILY):
@@ -373,7 +415,6 @@ class SpeechServer(speechserver.SpeechServer):
             family = defaultACSS[ACSS.FAMILY]
             familyName = family[speechserver.VoiceFamily.NAME]
 
-        voices = self.__driver.getAllVoices()
         found = False
         for voice in voices:
             if (not familyName) or (voice.name == familyName):
@@ -453,17 +494,20 @@ class SpeechServer(speechserver.SpeechServer):
                         speechserver.SayAllContext.PROGRESS)
                 elif type == GNOME.Speech.speech_callback_speech_ended:
                     try:
-                        [self.__sayAll.currentContext, acss] = \
-                            self.__sayAll.utteranceIterator.next()
-                        debug.println(debug.LEVEL_INFO,
-                                      "SPEECH OUTPUT: '" \
-                                      + self.__sayAll.currentContext.utterance\
-                                      + "'")
-                        log.info("'%s'" \
-                                 % self.__sayAll.currentContext.utterance)
-                        self.__sayAll.idForCurrentContext = self.__speak(
-                            self.__sayAll.currentContext.utterance,
-                            acss)
+                        while True:
+                            [self.__sayAll.currentContext, acss] = \
+                                self.__sayAll.utteranceIterator.next()
+                            utterance = self.__sayAll.currentContext.utterance
+                            debug.println(debug.LEVEL_INFO,
+                                          "SPEECH OUTPUT: '" \
+                                          + utterance \
+                                          + "'")
+                            log.info("'%s'" % utterance)
+                            if utterance and len(utterance)\
+                               and not utterance.isspace():
+                                self.__sayAll.idForCurrentContext = \
+                                    self.__speak(utterance, acss)
+                                break
                     except StopIteration:
                         self.__isSpeaking = False
                         context.currentOffset = context.endOffset
@@ -651,7 +695,30 @@ class SpeechServer(speechserver.SpeechServer):
                 #
                 isSpecial = isPrev and isNext and (oldText[i] == ".")
 
-                if (len(oldText) == 1) or isSpecial or (style <= level):
+                # If this is a dash and the users punctuation level is not
+                # NONE and the previous character is a white space character,
+                # and the next character is a dollar sign or a digit, then
+                # always speak it. See bug #392939.
+                #
+                prevCharMatches = nextCharMatches = False
+                if orca_state.activeScript:
+                    currencySymbols = \
+                        orca_state.activeScript.getUnicodeCurrencySymbols()
+                if i == 0:
+                    prevCharMatches = True
+                if i > 0:
+                    prevCharMatches = (oldText[i - 1] in string.whitespace)
+                if i < (len(oldText) - 1):
+                    nextCharMatches = (oldText[i + 1] in string.digits or \
+                                       oldText[i + 1] in currencySymbols)
+
+                if oldText[i] == "-" and \
+                   style != settings.PUNCTUATION_STYLE_NONE and \
+                   prevCharMatches and nextCharMatches:
+                    if isPrev:
+                        newText += " "
+                    newText += _("minus")
+                elif (len(oldText) == 1) or isSpecial or (style <= level):
                     if isPrev:
                         newText += " "
                     newText += chnames.getCharacterName(oldText[i])
@@ -706,7 +773,8 @@ class SpeechServer(speechserver.SpeechServer):
             return -1
 
         text = self.__addVerbalizedPunctuation(text)
-        text = util.adjustForPronunciation(text)
+        if orca_state.activeScript:
+            text = orca_state.activeScript.adjustForPronunciation(text)
 
         try:
             # [[[TODO: WDW - back this stop out for now.  The problem is
