@@ -19,9 +19,9 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 2050 2007-02-25 22:40:48Z wwalker $"
-__version__   = "$Revision: 2050 $"
-__date__      = "$Date: 2007-02-25 17:40:48 -0500 (Sun, 25 Feb 2007) $"
+__id__        = "$Id: orca.py 2209 2007-03-28 00:05:34Z wwalker $"
+__version__   = "$Revision: 2209 $"
+__date__      = "$Date: 2007-03-27 20:05:34 -0400 (Tue, 27 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -64,7 +64,6 @@ import settings
 import speech
 
 import threading
-import util
 
 from input_event import BrailleEvent
 from input_event import KeyboardEvent
@@ -412,28 +411,6 @@ def cycleDebugLevel(script=None, inputEvent=None):
 
     return True
 
-def printApps(script=None, inputEvent=None):
-    """Prints a list of all applications to stdout."""
-    util.printApps()
-    return True
-
-def printActiveApp(script=None, inputEvent=None):
-    """Prints the currently active application."""
-    util.printActiveApp()
-    return True
-
-def printAncestry(script=None, inputEvent=None):
-    """Prints the ancestry for the current locusOfFocus"""
-    util.printAncestry(orca_state.locusOfFocus)
-    return True
-
-def printHierarchy(script=None, inputEvent=None):
-    """Prints the application for the current locusOfFocus"""
-    if orca_state.locusOfFocus:
-        util.printHierarchy(orca_state.locusOfFocus.app,
-                            orca_state.locusOfFocus)
-    return True
-
 ########################################################################
 #                                                                      #
 # METHODS FOR PRE-PROCESSING AND MASSAGING KEYBOARD EVENTS.            #
@@ -742,10 +719,12 @@ def _processKeyboardEvent(event):
             if (not consumed) and settings.learnModeEnabled:
                 if keyboardEvent.type \
                     == atspi.Accessibility.KEY_PRESSED_EVENT:
-                    clickCount = util.getClickCount(orca_state.lastInputEvent,
+                    clickCount = orca_state.activeScript.getClickCount(\
+                                                orca_state.lastInputEvent,
                                                 keyboardEvent)
                     if clickCount == 2:
-                        util.phoneticSpellCurrentItem(keyboardEvent.event_string)
+                        orca_state.activeScript.phoneticSpellCurrentItem(\
+                            keyboardEvent.event_string)
                     else:
                         # Check to see if there are localized words to be
                         # spoken for this key event.
@@ -1067,25 +1046,7 @@ def start(registry):
         signal.signal(signal.SIGALRM, settings.timeoutCallback)
         signal.alarm(settings.timeoutTime)
 
-    try:
-        speech.speak(_("Welcome to Orca."))
-        braille.displayMessage(_("Welcome to Orca."))
-    except:
-        debug.printException(debug.LEVEL_SEVERE)
-
     if not _PRESENTATION_MANAGERS:
-
-        # [[[WDW - comment out hierarchical_presenter for now.  It
-        # relies on the list of known applications, and we've disabled
-        # that due to a hang in a call to getChildAtIndex in
-        # util.getKnownApplications.]]]
-        #
-        #import focus_tracking_presenter
-        #import hierarchical_presenter
-        #_PRESENTATION_MANAGERS = \
-        #    [focus_tracking_presenter.FocusTrackingPresenter(),
-        #     hierarchical_presenter.HierarchicalPresenter()]
-
         import focus_tracking_presenter
         _PRESENTATION_MANAGERS = \
             [focus_tracking_presenter.FocusTrackingPresenter()]
@@ -1390,6 +1351,13 @@ def main():
     registry = atspi.Registry()
     init(registry)
 
+    try:
+        message = _("Welcome to Orca.")
+        speech.speak(message)
+        braille.displayMessage(message)
+    except:
+        debug.printException(debug.LEVEL_SEVERE)
+
     # Check to see if the user wants the configuration GUI. It's
     # done here so that the user's existing preferences can be used
     # to set the initial GUI state.  We'll also force the set to
