@@ -24,9 +24,9 @@
 
 """Displays a GUI for the user to set Orca preferences."""
 
-__id__        = "$Id: orca_gui_prefs.py 1973 2007-02-02 23:22:35Z wwalker $"
-__version__   = "$Revision: 1973 $"
-__date__      = "$Date: 2007-02-02 18:22:35 -0500 (Fri, 02 Feb 2007) $"
+__id__        = "$Id: orca_gui_prefs.py 2134 2007-03-07 17:26:34Z richb $"
+__version__   = "$Revision: 2134 $"
+__date__      = "$Date: 2007-03-07 12:26:34 -0500 (Wed, 07 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -2026,6 +2026,10 @@ class orcaSetupGUI(orca_glade.GladeWrapper):
 def showPreferencesUI():
     global OS
 
+    line = _("Starting Orca Preferences. This may take a while.")
+    braille.displayMessage(line)
+    speech.speak(line)
+
     if not OS:
         gladeFile = os.path.join(platform.prefix,
                                  platform.datadirname,
