@@ -19,9 +19,9 @@
 
 """Custom script for StarOffice and OpenOffice."""
 
-__id__        = "$Id: StarOffice.py 1996 2007-02-11 18:07:28Z joanied $"
-__version__   = "$Revision: 1996 $"
-__date__      = "$Date: 2007-02-11 13:07:28 -0500 (Sun, 11 Feb 2007) $"
+__id__        = "$Id: StarOffice.py 2204 2007-03-27 15:48:07Z richb $"
+__version__   = "$Revision: 2204 $"
+__date__      = "$Date: 2007-03-27 11:48:07 -0400 (Tue, 27 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -39,155 +39,9 @@ import orca.speech as speech
 import orca.speechgenerator as speechgenerator
 import orca.settings as settings
 import orca.keybindings as keybindings
-import orca.util as util
 
 from orca.orca_i18n import _ # for gettext support
 
-inputLineForCell = None
-
-# Dictionaries for the calc dynamic row and column headers.
-#
-dynamicColumnHeaders = {}
-dynamicRowHeaders = {}
-
-def adjustForWriterTable(obj):
-    """Check to see if we are in Writer, where the object with focus is a
-    paragraph, and the parent is the table cell. If it is, then, return the
-    parent table cell otherwise return the current object.
-
-    Arguments:
-    - obj: the accessible object to check.
-
-    Returns parent table cell (if in a Writer table ) or the current object.
-    """
-
-    if obj.role == rolenames.ROLE_PARAGRAPH and \
-       obj.parent.role == rolenames.ROLE_TABLE_CELL:
-        return obj.parent
-    else:
-        return obj
-
-def getTable(obj):
-    """Get the table that this table cell is in.
-
-    Arguments:
-    - obj: the table cell.
-
-    Return the table that this table cell is in, or None if this object
-    isn't in a table.
-    """
-
-    table = None
-    obj = adjustForWriterTable(obj)
-    if obj.role == rolenames.ROLE_TABLE_CELL and obj.parent:
-        table = obj.parent.table
-
-    return table
-
-def getDynamicColumnHeaderCell(obj, column):
-    """Given a table cell, return the dynamic column header cell associated
-    with it.
-
-    Arguments:
-    - obj: the table cell.
-    - column: the column that this dynamic header is on.
-
-    Return the dynamic column header cell associated with the given table cell.
-    """
-
-    obj = adjustForWriterTable(obj)
-    accCell = None
-    parent = obj.parent
-    if parent and parent.table:
-        row = parent.table.getRowAtIndex(obj.index)
-        cell = parent.table.getAccessibleAt(row, column)
-        accCell = atspi.Accessible.makeAccessible(cell)
-
-    return accCell
-
-def getDynamicRowHeaderCell(obj, row):
-    """Given a table cell, return the dynamic row header cell associated
-    with it.
-
-    Arguments:
-    - obj: the table cell.
-    - row: the row that this dynamic header is on.
-
-    Return the dynamic row header cell associated with the given table cell.
-    """
-
-    obj = adjustForWriterTable(obj)
-    accCell = None
-    parent = obj.parent
-    if parent and parent.table:
-        column = parent.table.getColumnAtIndex(obj.index)
-        cell = parent.table.getAccessibleAt(row, column)
-        accCell = atspi.Accessible.makeAccessible(cell)
-
-    return accCell
-
-def locateInputLine(obj):
-    """Return the spread sheet input line. This only needs to be found
-    the very first time a spread sheet table cell gets focus. We use the
-    table cell to work back up the component hierarchy until we have found
-    the common panel that both it and the input line reside in. We then
-    use that as the base component to search for a component which has a
-    paragraph role. This will be the input line.
-
-    Arguments:
-    - obj: the spread sheet table cell that has just got focus.
-
-    Returns the spread sheet input line component.
-    """
-
-    inputLine = None
-    panel = obj.parent.parent.parent.parent
-    if panel and panel.role == rolenames.ROLE_PANEL:
-        allParagraphs = util.findByRole(panel, rolenames.ROLE_PARAGRAPH)
-        if len(allParagraphs) == 1:
-            inputLine = allParagraphs[0]
-        else:
-            debug.println(debug.LEVEL_SEVERE,
-                  "StarOffice: locateInputLine: incorrect paragraph count.")
-    else:
-        debug.println(debug.LEVEL_SEVERE,
-                  "StarOffice: locateInputLine: couldn't find common panel.")
-
-    return inputLine
-
-def isSpreadSheetCell(obj):
-    """Return an indication of whether the given obj is a spread sheet
-    table cell.
-
-    Arguments:
-    - obj: the object to check.
-
-    Returns True if this is a table cell, False otherwise.
-    """
-
-    found = False
-    rolesList = [rolenames.ROLE_TABLE_CELL, \
-                 rolenames.ROLE_TABLE, \
-                 rolenames.ROLE_UNKNOWN, \
-                 rolenames.ROLE_SCROLL_PANE, \
-                 rolenames.ROLE_PANEL, \
-                 rolenames.ROLE_ROOT_PANE, \
-                 rolenames.ROLE_FRAME, \
-                 rolenames.ROLE_APPLICATION]
-    if util.isDesiredFocusedItem(obj, rolesList):
-        # We've found a table cell with the correct hierarchy. Now check
-        # that we are in a spreadsheet as opposed to the writer application.
-        # See bug #382408.
-        #
-        current = obj.parent
-        while current.role != rolenames.ROLE_APPLICATION:
-            if current.role == rolenames.ROLE_FRAME and \
-               (current.name and current.name.endswith(_("Calc"))):
-                found = True
-            current = current.parent
-
-    return found
-
 class BrailleGenerator(braillegenerator.BrailleGenerator):
     """Overrides _getBrailleRegionsForTableCellRow so that , when we are
     in a spread sheet, we can braille the dynamic row and column headers
@@ -211,9 +65,6 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
         and the second element is the Region which should get focus.
         """
 
-        global dynamicColumnHeaders, dynamicRowHeaders
-        global getColumnHeaderCell, getRowHeaderCell, isSpreadSheetCell
-
         regions = []
 
         # Check to see if this spread sheet cell has either a dynamic
@@ -221,14 +72,14 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
         # If it does, then braille those first before brailling the
         # cell contents.
         #
-        table = getTable(obj)
+        table = self._script.getTable(obj)
         parent = obj.parent
 
         if parent.__dict__.has_key("lastColumn") and \
            parent.lastColumn != parent.table.getColumnAtIndex(obj.index):
-            if dynamicColumnHeaders.has_key(table):
-                row = dynamicColumnHeaders[table]
-                header = getDynamicRowHeaderCell(obj, row)
+            if self._script.dynamicColumnHeaders.has_key(table):
+                row = self._script.dynamicColumnHeaders[table]
+                header = self._script.getDynamicRowHeaderCell(obj, row)
                 if header.childCount > 0:
                     for i in range(0, header.childCount):
                         child = header.child(i)
@@ -242,9 +93,9 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
 
         if parent.__dict__.has_key("lastRow") and \
            parent.lastRow != parent.table.getRowAtIndex(obj.index):
-            if dynamicRowHeaders.has_key(table):
-                column = dynamicRowHeaders[table]
-                header = getDynamicColumnHeaderCell(obj, column)
+            if self._script.dynamicRowHeaders.has_key(table):
+                column = self._script.dynamicRowHeaders[table]
+                header = self._script.getDynamicColumnHeaderCell(obj, column)
                 if header.childCount > 0:
                     for i in range(0, header.childCount):
                         child = header.child(i)
@@ -256,7 +107,7 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
                     if text:
                         regions.append(braille.Region(" " + text + " "))
 
-        if isSpreadSheetCell(obj):
+        if self._script.isSpreadSheetCell(obj):
 
             # Adding in a check here to make sure that the parent is a
             # valid table. It's possible that the parent could be a
@@ -331,21 +182,20 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
         and the second element is the Region which should get focus.
         """
 
-        global inputLineForCell, isSpreadSheetCell, locateInputLine
-
-        if isSpreadSheetCell(obj):
-            if inputLineForCell == None:
-                inputLineForCell = locateInputLine(obj)
+        if self._script.isSpreadSheetCell(obj):
+            if self._script.inputLineForCell == None:
+                self._script.inputLineForCell = \
+                            self._script.locateInputLine(obj)
 
             regions = []
-            text = util.getDisplayedText(obj)
+            text = self._script.getDisplayedText(obj)
             componentRegion = braille.Component(obj, text)
             regions.append(componentRegion)
 
             # If the spread sheet table cell has something in it, then we
             # want to append the name of the cell (which will be its location).
-            # Note that if the cell was empty, then util.getDisplayedText will
-            # have already done this for us.
+            # Note that if the cell was empty, then 
+            # self._script.getDisplayedText will have already done this for us.
             #
             if obj.text:
                 objectText = self._script.getText(obj, 0, -1)
@@ -446,9 +296,6 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
         Returns a list of utterances to be spoken for the object.
         """
 
-        global dynamicColumnHeaders, dynamicRowHeaders
-        global getColumnHeaderCell, getRowHeaderCell, isSpreadSheetCell
-
         utterances = []
 
         if not already_focused:
@@ -458,15 +305,15 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
             # If it does, then speak those first before speaking the cell
             # contents.
             #
-            table = getTable(obj)
+            table = self._script.getTable(obj)
             parent = obj.parent
 
             if parent.__dict__.has_key("lastColumn") and \
                parent.lastColumn != \
                parent.table.getColumnAtIndex(obj.index):
-                if dynamicColumnHeaders.has_key(table):
-                    row = dynamicColumnHeaders[table]
-                    header = getDynamicRowHeaderCell(obj, row)
+                if self._script.dynamicColumnHeaders.has_key(table):
+                    row = self._script.dynamicColumnHeaders[table]
+                    header = self._script.getDynamicRowHeaderCell(obj, row)
                     if header.childCount > 0:
                         for i in range(0, header.childCount):
                             child = header.child(i)
@@ -480,9 +327,10 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
 
             if parent.__dict__.has_key("lastRow") and \
                parent.lastRow != parent.table.getRowAtIndex(obj.index):
-                if dynamicRowHeaders.has_key(table):
-                    column = dynamicRowHeaders[table]
-                    header = getDynamicColumnHeaderCell(obj, column)
+                if self._script.dynamicRowHeaders.has_key(table):
+                    column = self._script.dynamicRowHeaders[table]
+                    header = self._script.getDynamicColumnHeaderCell(obj, 
+                                                                     column)
                     if header.childCount > 0:
                         for i in range(0, header.childCount):
                             child = header.child(i)
@@ -494,7 +342,7 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
                         if text:
                             utterances.append(text)
 
-        if isSpreadSheetCell(obj):
+        if self._script.isSpreadSheetCell(obj):
             if not already_focused:
                 if settings.readTableCellRow:
                     parent = obj.parent
@@ -547,13 +395,12 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
         Returns a list of utterances to be spoken for the object.
         """
 
-        global inputLineForCell, isSpreadSheetCell, locateInputLine
-
-        if isSpreadSheetCell(obj):
+        if self._script.isSpreadSheetCell(obj):
             utterances = []
 
-            if inputLineForCell == None:
-                inputLineForCell = locateInputLine(obj)
+            if self._script.inputLineForCell == None:
+                self._script.inputLineForCell = \
+                            self._script.locateInputLine(obj)
 
             if obj.text:
                 objectText = self._script.getText(obj, 0, -1)
@@ -661,6 +508,15 @@ class Script(default.Script):
         #
         self.lastCell = None
 
+        # The spreadsheet input line.
+        #
+        self.inputLineForCell = None
+
+        # Dictionaries for the calc dynamic row and column headers.
+        #
+        self.dynamicColumnHeaders = {}
+        self.dynamicRowHeaders = {}
+
         # The following variables will be used to try to determine if we've
         # already handled this misspelt word (see readMisspeltWord() for
         # more details.
@@ -766,6 +622,147 @@ class Script(default.Script):
 
         return keyBindings
 
+    def adjustForWriterTable(self, obj):
+        """Check to see if we are in Writer, where the object with focus 
+        is a paragraph, and the parent is the table cell. If it is, then, 
+        return the parent table cell otherwise return the current object.
+
+        Arguments:
+        - obj: the accessible object to check.
+
+        Returns parent table cell (if in a Writer table ) or the current 
+        object.
+        """
+
+        if obj.role == rolenames.ROLE_PARAGRAPH and \
+           obj.parent.role == rolenames.ROLE_TABLE_CELL:
+            return obj.parent
+        else:
+            return obj
+
+    def getTable(self, obj):
+        """Get the table that this table cell is in.
+
+        Arguments:
+        - obj: the table cell.
+
+        Return the table that this table cell is in, or None if this object
+        isn't in a table.
+        """
+
+        table = None
+        obj = self.adjustForWriterTable(obj)
+        if obj.role == rolenames.ROLE_TABLE_CELL and obj.parent:
+            table = obj.parent.table
+
+        return table
+
+    def getDynamicColumnHeaderCell(self, obj, column):
+        """Given a table cell, return the dynamic column header cell 
+        associated with it.
+
+        Arguments:
+        - obj: the table cell.
+        - column: the column that this dynamic header is on.
+
+        Return the dynamic column header cell associated with the given 
+        table cell.
+        """
+
+        obj = self.adjustForWriterTable(obj)
+        accCell = None
+        parent = obj.parent
+        if parent and parent.table:
+            row = parent.table.getRowAtIndex(obj.index)
+            cell = parent.table.getAccessibleAt(row, column)
+            accCell = atspi.Accessible.makeAccessible(cell)
+
+        return accCell
+
+    def getDynamicRowHeaderCell(self, obj, row):
+        """Given a table cell, return the dynamic row header cell 
+        associated with it.
+
+        Arguments:
+        - obj: the table cell.
+        - row: the row that this dynamic header is on.
+
+        Return the dynamic row header cell associated with the given 
+        table cell.
+        """
+
+        obj = self.adjustForWriterTable(obj)
+        accCell = None
+        parent = obj.parent
+        if parent and parent.table:
+            column = parent.table.getColumnAtIndex(obj.index)
+            cell = parent.table.getAccessibleAt(row, column)
+            accCell = atspi.Accessible.makeAccessible(cell)
+    
+        return accCell
+
+    def locateInputLine(self, obj):
+        """Return the spread sheet input line. This only needs to be found
+        the very first time a spread sheet table cell gets focus. We use the
+        table cell to work back up the component hierarchy until we have found
+        the common panel that both it and the input line reside in. We then
+        use that as the base component to search for a component which has a
+        paragraph role. This will be the input line.
+
+        Arguments:
+        - obj: the spread sheet table cell that has just got focus.
+
+        Returns the spread sheet input line component.
+        """
+
+        inputLine = None 
+        panel = obj.parent.parent.parent.parent
+        if panel and panel.role == rolenames.ROLE_PANEL:
+            allParagraphs = self.findByRole(panel, rolenames.ROLE_PARAGRAPH)
+            if len(allParagraphs) == 1:
+                inputLine = allParagraphs[0]
+            else:
+                debug.println(debug.LEVEL_SEVERE,
+                    "StarOffice: locateInputLine: incorrect paragraph count.")
+        else: 
+            debug.println(debug.LEVEL_SEVERE,
+                  "StarOffice: locateInputLine: couldn't find common panel.")
+
+        return inputLine
+
+    def isSpreadSheetCell(self, obj):
+        """Return an indication of whether the given obj is a spread sheet
+        table cell.
+
+        Arguments:
+        - obj: the object to check.
+
+        Returns True if this is a table cell, False otherwise.
+        """
+
+        found = False
+        rolesList = [rolenames.ROLE_TABLE_CELL, \
+                     rolenames.ROLE_TABLE, \
+                     rolenames.ROLE_UNKNOWN, \
+                     rolenames.ROLE_SCROLL_PANE, \
+                     rolenames.ROLE_PANEL, \
+                     rolenames.ROLE_ROOT_PANE, \
+                     rolenames.ROLE_FRAME, \
+                     rolenames.ROLE_APPLICATION]
+        if self.isDesiredFocusedItem(obj, rolesList):
+            # We've found a table cell with the correct hierarchy. Now check
+            # that we are in a spreadsheet as opposed to the writer application.
+            # See bug #382408.
+            #
+            current = obj.parent
+            while current.role != rolenames.ROLE_APPLICATION:
+                if current.role == rolenames.ROLE_FRAME and \
+                   (current.name and current.name.endswith(_("Calc"))):
+                    found = True
+                current = current.parent
+
+        return found
+
     def checkForTableBoundry(self, oldFocus, newFocus):
         """Check to see if we've entered or left a table.
         When entering a table, announce the table dimensions.
@@ -817,9 +814,9 @@ class Script(default.Script):
 
         # Check to see if the current focus is a table cell.
         #
-        if isSpreadSheetCell(orca_state.locusOfFocus):
-            if inputLineForCell and inputLineForCell.text:
-                inputLine = self.getText(inputLineForCell, 0, -1)
+        if self.isSpreadSheetCell(orca_state.locusOfFocus):
+            if self.inputLineForCell and self.inputLineForCell.text:
+                inputLine = self.getText(self.inputLineForCell, 0, -1)
                 if not inputLine:
                     inputLine = _("empty")
                 debug.println(self.debugLevel,
@@ -837,7 +834,7 @@ class Script(default.Script):
         """
 
         row = None
-        cell = adjustForWriterTable(cell)
+        cell = self.adjustForWriterTable(cell)
         if cell.role == rolenames.ROLE_TABLE_CELL:
             parent = cell.parent
             if parent and parent.table:
@@ -856,7 +853,7 @@ class Script(default.Script):
         """
 
         column = None
-        cell = adjustForWriterTable(cell)
+        cell = self.adjustForWriterTable(cell)
         if cell.role == rolenames.ROLE_TABLE_CELL:
             parent = cell.parent
             if parent and parent.table:
@@ -879,24 +876,22 @@ class Script(default.Script):
         - inputEvent: if not None, the input event that caused this action.
         """
 
-        global dynamicColumnHeaders, getTable
-
         debug.println(self.debugLevel, "StarOffice.setDynamicColumnHeaders.")
 
-        clickCount = util.getClickCount(self.lastDynamicEvent, inputEvent)
-        table = getTable(orca_state.locusOfFocus)
+        clickCount = self.getClickCount(self.lastDynamicEvent, inputEvent)
+        table = self.getTable(orca_state.locusOfFocus)
         if table:
             row = self.getTableRow(orca_state.locusOfFocus)
             if clickCount == 2:
                 try:
-                    del dynamicColumnHeaders[table]
+                    del self.dynamicColumnHeaders[table]
                     line = _("Dynamic column header cleared.")
                     speech.speak(line)
                     braille.displayMessage(line)
                 except:
                     pass
             else:
-                dynamicColumnHeaders[table] = row
+                self.dynamicColumnHeaders[table] = row
                 line = _("Dynamic column header set for row ") + str(row+1)
                 speech.speak(line)
                 braille.displayMessage(line)
@@ -942,24 +937,22 @@ class Script(default.Script):
         - inputEvent: if not None, the input event that caused this action.
         """
 
-        global dynamicRowHeaders, getTable
-
         debug.println(self.debugLevel, "StarOffice.setDynamicRowHeaders.")
 
-        clickCount = util.getClickCount(self.lastDynamicEvent, inputEvent)
-        table = getTable(orca_state.locusOfFocus)
+        clickCount = self.getClickCount(self.lastDynamicEvent, inputEvent)
+        table = self.getTable(orca_state.locusOfFocus)
         if table:
             column = self.getTableColumn(orca_state.locusOfFocus)
             if clickCount == 2:
                 try:
-                    del dynamicRowHeaders[table]
+                    del self.dynamicRowHeaders[table]
                     line = _("Dynamic row header cleared.")
                     speech.speak(line)
                     braille.displayMessage(line)
                 except:
                     pass
             else:
-                dynamicRowHeaders[table] = column
+                self.dynamicRowHeaders[table] = column
                 line = _("Dynamic row header set for column %s") % \
                        self.columnConvert(column+1)
                 speech.speak(line)
@@ -982,13 +975,14 @@ class Script(default.Script):
         - pane: the option pane in the spell check dialog.
         """
 
-        paragraph = util.findByRole(pane, rolenames.ROLE_PARAGRAPH)
+        paragraph = self.findByRole(pane, rolenames.ROLE_PARAGRAPH)
 
         # Determine which word is the misspelt word. This word will have
         # non-default text attributes associated with it.
 
         textLength = paragraph[0].text.characterCount
         startFound = False
+        startOff = 0
         endOff = textLength
         for i in range(0, textLength):
             attributes = paragraph[0].text.getAttributes(i)
@@ -1025,7 +1019,7 @@ class Script(default.Script):
         text = self.getText(paragraph[0], 0, -1)
         allTokens = text.split()
 
-        util.speakMisspeltWord(allTokens, badWord)
+        self.speakMisspeltWord(allTokens, badWord)
 
         # Save misspelt word information for comparison purposes next
         # time around.
@@ -1054,9 +1048,9 @@ class Script(default.Script):
         for i in range(0, nLinks):
             links.append(obj.hypertext.getLink(i))
 
-        for i in range(0, len(links)):
-            if links[i].endIndex > startOffset and \
-               links[i].endIndex <= endOffset:
+        for link in links:
+            if link.endIndex > startOffset and \
+               link.endIndex <= endOffset:
                 return True
 
         return False
@@ -1077,7 +1071,7 @@ class Script(default.Script):
         voices = settings.voices
 
         for i in range(startOffset, endOffset):
-            if util.getLinkIndex(obj, i) >= 0:
+            if self.getLinkIndex(obj, i) >= 0:
                 voice = voices[settings.HYPERLINK_VOICE]
                 break
             elif word.isupper():
@@ -1121,7 +1115,7 @@ class Script(default.Script):
         - label: the Setup dialog Label.
         """
 
-        text = util.getDisplayedText(label)
+        text = self.getDisplayedText(label)
         if text:
             speech.speak(text)
 
@@ -1132,9 +1126,9 @@ class Script(default.Script):
         - panel: the Setup panel.
         """
 
-        allLabels = util.findByRole(panel, rolenames.ROLE_LABEL)
-        for i in range(0, len(allLabels)):
-            self.speakSetupLabel(allLabels[i])
+        allLabels = self.findByRole(panel, rolenames.ROLE_LABEL)
+        for label in allLabels:
+            self.speakSetupLabel(label)
 
     # This method tries to detect and handle the following cases:
     # 0) Writer: find command.
@@ -1160,7 +1154,7 @@ class Script(default.Script):
                                event,
                                event.source.toString())
 
-        # util.printAncestry(event.source)
+        # self.printAncestry(event.source)
 
         # 0) Writer: find command
         #
@@ -1192,11 +1186,11 @@ class Script(default.Script):
                      rolenames.ROLE_PANEL, \
                      rolenames.ROLE_ROOT_PANE, \
                      rolenames.ROLE_FRAME]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                   "StarOffice.locusOfFocusChanged - Writer: text paragraph.")
 
-            result = util.getTextLineAtCaret(event.source)
+            result = self.getTextLineAtCaret(event.source)
             result[0] = result[0].decode("UTF-8")
 
             if oldLocusOfFocus.role == rolenames.ROLE_MENU_ITEM and \
@@ -1258,7 +1252,7 @@ class Script(default.Script):
                      rolenames.ROLE_OPTION_PANE, \
                      rolenames.ROLE_DIALOG, \
                      rolenames.ROLE_APPLICATION]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             pane = event.source.parent
             if pane.name.startswith(_("Spellcheck:")):
                 debug.println(self.debugLevel,
@@ -1283,7 +1277,7 @@ class Script(default.Script):
                          rolenames.ROLE_OPTION_PANE, \
                          rolenames.ROLE_DIALOG, \
                          rolenames.ROLE_APPLICATION]
-            if util.isDesiredFocusedItem(event.source, rolesList):
+            if self.isDesiredFocusedItem(event.source, rolesList):
                 debug.println(self.debugLevel,
                     "StarOffice.locusOfFocusChanged - Setup dialog: " \
                     + "License Agreement screen: Scroll Down button.")
@@ -1298,7 +1292,7 @@ class Script(default.Script):
                          rolenames.ROLE_OPTION_PANE, \
                          rolenames.ROLE_DIALOG, \
                          rolenames.ROLE_APPLICATION]
-            if util.isDesiredFocusedItem(event.source, rolesList):
+            if self.isDesiredFocusedItem(event.source, rolesList):
                 debug.println(self.debugLevel,
                     "StarOffice.locusOfFocusChanged - Setup dialog: " \
                     + "License Agreement screen: accept button.")
@@ -1311,7 +1305,7 @@ class Script(default.Script):
                          rolenames.ROLE_OPTION_PANE, \
                          rolenames.ROLE_DIALOG, \
                          rolenames.ROLE_APPLICATION]
-            if util.isDesiredFocusedItem(event.source, rolesList):
+            if self.isDesiredFocusedItem(event.source, rolesList):
                 debug.println(self.debugLevel,
                     "StarOffice.locusOfFocusChanged - Setup dialog: " \
                     + "Personal Data: Transfer Personal Data check box.")
@@ -1324,7 +1318,7 @@ class Script(default.Script):
                         rolenames.ROLE_OPTION_PANE, \
                         rolenames.ROLE_DIALOG, \
                         rolenames.ROLE_APPLICATION]
-            if util.isDesiredFocusedItem(event.source, rolesList) and \
+            if self.isDesiredFocusedItem(event.source, rolesList) and \
                event.source.name == _("First name"):
                 debug.println(self.debugLevel,
                     "StarOffice.locusOfFocusChanged - Setup dialog: " \
@@ -1334,16 +1328,16 @@ class Script(default.Script):
                 # (and not the ones that have LABEL_FOR relationships).
                 #
                 panel = event.source.parent
-                allLabels = util.findByRole(panel, rolenames.ROLE_LABEL)
-                for i in range(0, len(allLabels)):
-                    relations = allLabels[i].relations
+                allLabels = self.findByRole(panel, rolenames.ROLE_LABEL)
+                for label in allLabels:
+                    relations = label.relations
                     hasLabelFor = False
                     for relation in relations:
                         if relation.getRelationType() \
                                == atspi.Accessibility.RELATION_LABEL_FOR:
                             hasLabelFor = True
                     if not hasLabelFor:
-                        self.speakSetupLabel(allLabels[i])
+                        self.speakSetupLabel(label)
 
             # Check for 5. Registration: Register Now radio button.
             #
@@ -1352,7 +1346,7 @@ class Script(default.Script):
                         rolenames.ROLE_OPTION_PANE, \
                         rolenames.ROLE_DIALOG, \
                         rolenames.ROLE_APPLICATION]
-            if util.isDesiredFocusedItem(event.source, rolesList):
+            if self.isDesiredFocusedItem(event.source, rolesList):
                 debug.println(self.debugLevel,
                     "StarOffice.locusOfFocusChanged - Setup dialog: " \
                     + "Registration: Register Now radio button.")
@@ -1371,7 +1365,7 @@ class Script(default.Script):
                      rolenames.ROLE_ROOT_PANE, \
                      rolenames.ROLE_FRAME, \
                      rolenames.ROLE_APPLICATION]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel, "StarOffice.locusOfFocusChanged - " \
                           + "Calc: cell editor.")
             return
@@ -1391,7 +1385,7 @@ class Script(default.Script):
                      rolenames.ROLE_FRAME, \
                      rolenames.ROLE_APPLICATION]
 
-        if util.isDesiredFocusedItem(event.source, rolesList) \
+        if self.isDesiredFocusedItem(event.source, rolesList) \
             and (not event.source.name or len(event.source.name) == 0):
             debug.println(self.debugLevel, "StarOffice.locusOfFocusChanged - " \
                           + "Calc: name box.")
@@ -1417,7 +1411,7 @@ class Script(default.Script):
                                event,
                                event.source.toString())
 
-        # util.printAncestry(event.source)
+        # self.printAncestry(event.source)
 
         # 1) Setup dialog.
         #
@@ -1429,14 +1423,13 @@ class Script(default.Script):
             debug.println(self.debugLevel,
                 "StarOffice.onWindowActivated - Setup dialog: Welcome screen.")
 
-            allPanels = util.findByRole(event.source.parent,
+            allPanels = self.findByRole(event.source.parent,
                                         rolenames.ROLE_PANEL)
-            for i in range(0, len(allPanels)):
-                if not allPanels[i].name:
-                    allLabels = util.findByRole(allPanels[i],
-                                                rolenames.ROLE_LABEL)
-                    for i in range(0, len(allLabels)):
-                        self.speakSetupLabel(allLabels[i])
+            for panel in allPanels:
+                if not panel.name:
+                    allLabels = self.findByRole(panel, rolenames.ROLE_LABEL)
+                    for label in allLabels:
+                        self.speakSetupLabel(label)
         else:
             # Pass the event onto the parent class to be handled in the
             # default way.
@@ -1461,7 +1454,7 @@ class Script(default.Script):
                                event,
                                event.source.toString())
 
-        # util.printAncestry(event.source)
+        # self.printAncestry(event.source)
 
         # 1) Writer: spell checking dialog.
         #
@@ -1480,7 +1473,7 @@ class Script(default.Script):
         rolesList = [rolenames.ROLE_OPTION_PANE, \
                      rolenames.ROLE_DIALOG, \
                      rolenames.ROLE_APPLICATION]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             pane = event.source
             if pane.name.startswith(_("Spellcheck:")):
                 debug.println(self.debugLevel,
@@ -1656,7 +1649,7 @@ class Script(default.Script):
                                event,
                                event.source.toString())
 
-        # util.printAncestry(event.source)
+        # self.printAncestry(event.source)
 
         # 1) Calc: spread sheet input line.
         #
@@ -1674,7 +1667,7 @@ class Script(default.Script):
                      rolenames.ROLE_ROOT_PANE, \
                      rolenames.ROLE_FRAME, \
                      rolenames.ROLE_APPLICATION]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             if orca_state.locusOfFocus.role == rolenames.ROLE_TABLE_CELL:
                 cell = orca_state.locusOfFocus
 
@@ -1689,8 +1682,9 @@ class Script(default.Script):
                     if cell.text:
                         cellText = self.getText(cell, 0, -1)
                         if cellText and len(cellText):
-                            if inputLineForCell and inputLineForCell.text:
-                                inputLine = self.getText(inputLineForCell,0,-1)
+                            if self.inputLineForCell and \
+                               self.inputLineForCell.text:
+                                inputLine = self.getText(self.inputLineForCell,0,-1)
                                 if inputLine and \
                                     (len(inputLine) > 1) and \
                                     (inputLine[0] == "="):
@@ -1895,3 +1889,26 @@ class Script(default.Script):
         if line[1] == 0 and line[2] == 0:
             return settings.speakBlankLines
 
+    def onTextInserted(self, event):
+        """Called whenever text is inserted into an object.  Overridden here
+        to handle the case when the inserted text was pasted via middle mouse
+        click.
+
+        Arguments:
+        - event: the Event
+        """
+
+        # Because event.source is the paragraph where the text was inserted
+        # and locusOfFocus is the selected text, the default onTextInserted
+        # will return without speaking the text that was pasted.
+        #
+        text = event.any_data
+        if isinstance(orca_state.lastInputEvent, 
+                        input_event.MouseButtonEvent) and \
+             orca_state.lastInputEvent.button == "2":
+            if text.isupper():
+                speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
+            else:
+                speech.speak(text)
+        else:
+            default.Script.onTextInserted(self, event)
