@@ -19,9 +19,9 @@
 
 """Custom script for gedit."""
 
-__id__        = "$Id: gedit.py,v 1.23 2006/11/06 16:41:04 wwalker Exp $"
-__version__   = "$Revision: 1.23 $"
-__date__      = "$Date: 2006/11/06 16:41:04 $"
+__id__        = "$Id: gedit.py 2140 2007-03-07 20:04:06Z richb $"
+__version__   = "$Revision: 2140 $"
+__date__      = "$Date: 2007-03-07 15:04:06 -0500 (Wed, 07 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -34,7 +34,6 @@ import orca.orca_state as orca_state
 import orca.rolenames as rolenames
 import orca.speech as speech
 import orca.speechgenerator as speechgenerator
-import orca.util as util
 
 from orca.orca_i18n import _
 
@@ -133,13 +132,13 @@ class Script(default.Script):
         # Spelling dialog. Look for the one that isn't a label to
         # another component.
         #
-        allLabels = util.findByRole(panel, rolenames.ROLE_LABEL)
-        for i in range(0, len(allLabels)):
-            if allLabels[i].name.startswith(_("Change to:")) or \
-               allLabels[i].name.startswith(_("Misspelled word:")):
+        allLabels = self.findByRole(panel, rolenames.ROLE_LABEL)
+        for label in allLabels:
+            if label.name.startswith(_("Change to:")) or \
+               label.name.startswith(_("Misspelled word:")):
                 continue
             else:
-                badWord = allLabels[i].name
+                badWord = label.name
                 break
 
         # Note that we often get two or more of these focus or property-change
@@ -149,7 +148,7 @@ class Script(default.Script):
         # was called. If they are the same then we ignore it.
 
         if self.textArea != None:
-            allText = util.findByRole(self.textArea, rolenames.ROLE_TEXT)
+            allText = self.findByRole(self.textArea, rolenames.ROLE_TEXT)
             caretPosition = allText[0].text.caretOffset
 
             debug.println(self.debugLevel, \
@@ -182,7 +181,7 @@ class Script(default.Script):
                 tokens = text.split()
                 allTokens += tokens
 
-            util.speakMisspeltWord(allTokens, badWord)
+            self.speakMisspeltWord(allTokens, badWord)
 
             # Save misspelt word information for comparison purposes
             # next time around.
@@ -210,9 +209,9 @@ class Script(default.Script):
                      rolenames.ROLE_DIALOG,
                      rolenames.ROLE_APPLICATION]
 
-        if (util.isDesiredFocusedItem(obj, rolesList1) \
+        if (self.isDesiredFocusedItem(obj, rolesList1) \
             and obj.name == _("Find")) \
-            or (util.isDesiredFocusedItem(obj, rolesList2) \
+            or (self.isDesiredFocusedItem(obj, rolesList2) \
                 and obj.parent.parent.parent.parent.name == _("Find")):
             return True
         else:
@@ -238,7 +237,7 @@ class Script(default.Script):
                                event,
                                event.source.toString())
 
-        # util.printAncestry(event.source)
+        # self.printAncestry(event.source)
 
         # 1) Text area (for caching handle for spell checking purposes).
         #
@@ -256,7 +255,7 @@ class Script(default.Script):
                      rolenames.ROLE_PAGE_TAB,
                      rolenames.ROLE_PAGE_TAB_LIST,
                      rolenames.ROLE_SPLIT_PANE]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                           "gedit.locusOfFocusChanged - text area.")
 
@@ -280,7 +279,7 @@ class Script(default.Script):
                      rolenames.ROLE_PANEL,
                      rolenames.ROLE_FILLER,
                      rolenames.ROLE_FRAME]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             frame = event.source.parent.parent.parent.parent
             if frame.name.startswith(_("Check Spelling")):
                 debug.println(self.debugLevel,
@@ -313,7 +312,7 @@ class Script(default.Script):
                                event,
                                event.source.toString())
 
-        # util.printAncestry(event.source)
+        # self.printAncestry(event.source)
 
         # 1) check spelling dialog.
         #
@@ -334,7 +333,7 @@ class Script(default.Script):
                      rolenames.ROLE_PANEL,
                      rolenames.ROLE_FILLER,
                      rolenames.ROLE_FRAME]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             frame = event.source.parent.parent.parent
             if frame.name.startswith(_("Check Spelling")):
                 debug.println(self.debugLevel,
@@ -402,7 +401,7 @@ class Script(default.Script):
                                event,
                                event.source.toString())
 
-        # util.printAncestry(event.source)
+        # self.printAncestry(event.source)
 
         # If we've received a text caret moved event and the current locus
         # of focus is on the Find button on the Find dialog or the combo
@@ -415,11 +414,11 @@ class Script(default.Script):
            and orca_state.lastInputEvent.event_string == "Return":
             debug.println(self.debugLevel, "gedit.onCaretMoved - find dialog.")
 
-            allComboBoxes = util.findByRole(orca_state.locusOfFocus.app,
+            allComboBoxes = self.findByRole(orca_state.locusOfFocus.app,
                                             rolenames.ROLE_COMBO_BOX)
-            phrase = util.getDisplayedText(allComboBoxes[0])
+            phrase = self.getDisplayedText(allComboBoxes[0])
             [text, caretOffset, startOffset] = \
-                util.getTextLineAtCaret(event.source)
+                self.getTextLineAtCaret(event.source)
             if text.lower().find(phrase) != -1:
                 speech.speak(_("Phrase found."))
                 utterances = self.speechGenerator.getSpeech(event.source, True)
