@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 2077 2007-03-02 23:42:02Z wwalker $"
-__version__   = "$Revision: 2077 $"
-__date__      = "$Date: 2007-03-02 18:42:02 -0500 (Fri, 02 Mar 2007) $"
+__id__        = "$Id: settings.py 2169 2007-03-13 15:28:45Z wwalker $"
+__version__   = "$Revision: 2169 $"
+__date__      = "$Date: 2007-03-13 11:28:45 -0400 (Tue, 13 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -203,7 +203,7 @@ silenceSpeech           = False
 # Settings that apply to the particular speech engine to
 # use as well details on the default voices to use.
 #
-speechFactoryModules    = ["espeechfactory","gnomespeechfactory"]
+speechFactoryModules    = ["espeechfactory","gnomespeechfactory","speechdispatcherfactory"]
 speechServerFactory     = "gnomespeechfactory"
 speechServerInfo        = None # None means let the factory decide.
 
